@@ -60,8 +60,6 @@ def asana_get_todos(workspace_name,filtering):
     # {'param': 'value', 'param': 'value'}
     # https://developers.asana.com/docs/get-tasks-from-a-project
     # print requests that python is making
-    # import logging
-    # logging.basicConfig(level=logging.DEBUG)
 
     opt_fields='name,due_on,completed,projects,notes'
     if filtering!='everyone':
@@ -74,7 +72,7 @@ def asana_get_todos(workspace_name,filtering):
     df = pd.DataFrame(tasks)
     return df
     
-def add_todo(task_text, expected_duration, workspace_name, project_id=0):
+def add_todo(task_text, expected_duration, workspace_id, project_name=0):
     tm = time.localtime()
     
     if expected_duration is None:
@@ -86,14 +84,15 @@ def add_todo(task_text, expected_duration, workspace_name, project_id=0):
     
     client = get_client()
     me = client.users.me()
-    if len(me['workspaces'])!=1:
-        workspace_name = 'Daily'
-        workspace_id = [ w['gid'] for w in me['workspaces'] if w['name'] == workspace_name][0]
-    else:
-        workspace_id = me['workspaces'][0]['gid']    
-        
-    projects = list(client.projects.get_projects_for_workspace(workspace_id))
     
+    if workspace_id is None: workspace_id = me['workspaces'][0]['gid']
+    projects = list(client.projects.get_projects_for_workspace(workspace_id))
+    if len(projects)!=1:
+        project_name = 'Daily'
+        project_id = [ w['gid'] for w in projects if w['name'] == project_name][0]
+    else:
+        project_id = 0
+        
     # docs https://developers.asana.com/docs/create-a-task
         
     data =  {'name': task_text,
